@@ -17,6 +17,7 @@ from typing import Dict, List, Optional, Tuple
 # PYPI imports
 import cmake
 import cmakegenerators
+import distro
 
 # Relative imports
 from bpybuild import BITNESS
@@ -43,6 +44,8 @@ def get_configure_commands(source: pathlib.Path, destination: pathlib.Path,
 
     if platform.system() == "Windows":
 
+        os_configure_args += ["-DWITH_WINDOWS_BUNDLE_CRT=OFF"]
+
         generators = [generator for generator in 
                       cmakegenerators.get_generators() if 
                       generator.name.startswith("Visual Studio")]
@@ -57,7 +60,7 @@ def get_configure_commands(source: pathlib.Path, destination: pathlib.Path,
 
         if len(filtered_generators) > 0:
 
-            generator_option : str = None
+            generator_option = None
 
             if BITNESS == 64:
 
@@ -89,6 +92,12 @@ def get_configure_commands(source: pathlib.Path, destination: pathlib.Path,
 
         os_configure_args += ["-DWITH_AUDASPACE=OFF"]
 
+        if distro.linux_distribution()[0].casefold() in ["debian", "raspbian"]:
+
+            # JEMALLOC breaks the import on debian-based linux distributions
+
+            os_configure_args += ["-DWITH_MEM_JEMALLOC=OFF"]
+
     elif platform.system() == "Darwin":
 
         os_configure_args += ["-DWITH_OPENMP=OFF", "-DWITH_AUDASPACE=OFF"]
@@ -97,7 +106,7 @@ def get_configure_commands(source: pathlib.Path, destination: pathlib.Path,
 
         commands.append(["make", "-C", str(source.absolute()), "update"])
 
-    if platform.system() == "Linux":
+    if platform.system() == "Linux"and distro.linux_distribution()[0].casefold() != "centos":
 
         commands.append([os.path.join(str(source.absolute()), 
                          "build_files", "build_environment", 
